using adminBlazor.Factories;
using adminBlazor.Models;

namespace TestUnit
{
    public class UserFactory_UT
    {
        public static IEnumerable<object[]> Dataset()
        {
            yield return new object[]
            {
                new UserModel[]
                {
                    new()
                {
                    Id = 0,
                    Password = "password",
                    Email = "email",
                    Name = "name",
                    Surname = "surname",
                    Nickname = "nickname",
                    ExtraTime = false,
                    Group = 5
                },
                new()
                {
                    Id = 1,
                    Password = "password2",
                    Email = "email2",
                    Name = "name2",
                    Surname = "surname2",
                    Nickname = "nickname2",
                    ExtraTime = true,
                    Group = 10
                },
                new()
                {
                    Id = 2,
                    Password = "password3",
                    Email = "email3",
                    Name = "name3",
                    Surname = "surname3",
                    Nickname = "nickname3",
                    ExtraTime = false,
                    Group = 15
                }
                }
            };
        }
        [Theory]
        [MemberData(nameof(Dataset))]
        public void Create_Validation(UserModel[] userMdls)
        {
            foreach (var userMdl in  userMdls)
            {
                var user = UserFactory.Create(userMdl);

                Assert.Equal(userMdl.Id, user.Id);
                Assert.Equal(userMdl.Password, user.Password);
                Assert.Equal(userMdl.Email, user.Email);
                Assert.Equal(userMdl.Name, user.Name);
                Assert.Equal(userMdl.Surname, user.Surname);
                Assert.Equal(userMdl.Nickname, user.Nickname);
                Assert.Equal(userMdl.ExtraTime, user.ExtraTime);
                Assert.Equal(userMdl.Group, user.Group);
            }
        }

        [Theory]
        [MemberData(nameof(Dataset))]
        public void Update_Validation(UserModel[] userMdls)
        {
            foreach (var userMdl in userMdls)
            {
                var user = UserFactory.Create(userMdl);

                userMdl.Password = "a";
                userMdl.Email = "a.a@a.com";
                userMdl.Name = "a";
                userMdl.Surname = "a";
                userMdl.Nickname = "a";
                userMdl.ExtraTime = true;
                userMdl.Group = 50;

                UserFactory.Update(user, userMdl);

                Assert.Equal(userMdl.Password, user.Password);
                Assert.Equal(userMdl.Email, user.Email);
                Assert.Equal(userMdl.Name, user.Name);
                Assert.Equal(userMdl.Surname, user.Surname);
                Assert.Equal(userMdl.Nickname, user.Nickname);
                Assert.Equal(userMdl.ExtraTime, user.ExtraTime);
                Assert.Equal(userMdl.Group, user.Group);
            }
        }

        [Theory]
        [MemberData(nameof(Dataset))]
        public void ToModel_Validation(UserModel[] userMdls)
        {
            foreach (var userMdl in userMdls)
            {
                var user = UserFactory.Create(userMdl);
                var userMdl2 = UserFactory.ToModel(user, Array.Empty<byte>());

                Assert.Equal(userMdl.Password, userMdl2.Password);
                Assert.Equal(userMdl.Email, userMdl2.Email);
                Assert.Equal(userMdl.Name, userMdl2.Name);
                Assert.Equal(userMdl.Surname, userMdl2.Surname);
                Assert.Equal(userMdl.Nickname, userMdl2.Nickname);
                Assert.Equal(userMdl.ExtraTime, userMdl2.ExtraTime);
                Assert.Equal(userMdl.Group, userMdl2.Group);
            }
        }
    }
}